summaryrefslogtreecommitdiff
path: root/ace/Auto_Ptr.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-08-16 15:10:18 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-08-16 15:10:18 +0000
commitbbd109640d28074f80c3971b2b6d1883e9c6ddf4 (patch)
treee2850f2f5e3029317dda4233179cf792edeaa1dc /ace/Auto_Ptr.h
parent50887b7ab365f7114480839a0210c714c17d4296 (diff)
downloadATCD-bbd109640d28074f80c3971b2b6d1883e9c6ddf4.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Auto_Ptr.h')
-rw-r--r--ace/Auto_Ptr.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/ace/Auto_Ptr.h b/ace/Auto_Ptr.h
index 6565f5a767b..fefc955421b 100644
--- a/ace/Auto_Ptr.h
+++ b/ace/Auto_Ptr.h
@@ -21,10 +21,12 @@
#include "ace/ACE.h"
+#if !defined (ACE_HAS_STANDARD_CPP_LIBRARY)
+
template <class X>
class ACE_Auto_Basic_Ptr
// = TITLE
// Implements the draft C++ standard ACE_Auto_Ptr abstraction.
// This class allows one to work on non-object (basic) types
{
public:
@@ -53,22 +55,23 @@ protected:
};
template <class X>
-class ACE_Auto_Ptr : public ACE_Auto_Basic_Ptr <X>
+class auto_ptr : public ACE_Auto_Basic_Ptr <X>
// = TITLE
// Implements the draft C++ standard ACE_Auto_Ptr abstraction.
{
public:
// = Initialization and termination methods
- ACE_Auto_Ptr (X *p = 0);
+ auto_ptr (X *p = 0);
X *operator-> () const;
};
+#endif /* ACE_HAS_STANDARD_CPP_LIBRARY */
template<class X>
class ACE_Auto_Basic_Array_Ptr
// = TITLE
// Implements an extension to the draft C++ standard ACE_Auto_Ptr
// abstraction. This class allows one to work on non-object
// (basic) types
{
@@ -102,7 +105,7 @@ protected:
template<class X>
class ACE_Auto_Array_Ptr : public ACE_Auto_Basic_Array_Ptr<X>
// = TITLE
// Implements an extension to the draft C++ standard ACE_Auto_Ptr
// abstraction.
{
public:
@@ -21,10 +21,12 @@
class ACE_Auto_Basic_Ptr
// = TITLE
- // Implements the draft C++ standard ACE_Auto_Ptr abstraction.
+ // Implements the draft C++ standard auto_ptr abstraction.
// This class allows one to work on non-object (basic) types
{
@@ -53,22 +55,23 @@ protected:
// = TITLE
- // Implements the draft C++ standard ACE_Auto_Ptr abstraction.
+ // Implements the draft C++ standard auto_ptr abstraction.
{
public:
@@ -53,22 +55,23 @@ protected:
class ACE_Auto_Basic_Array_Ptr
// = TITLE
- // Implements an extension to the draft C++ standard ACE_Auto_Ptr
+ // Implements an extension to the draft C++ standard auto_ptr
// abstraction. This class allows one to work on non-object
// (basic) types
@@ -102,7 +105,7 @@ protected:
class ACE_Auto_Array_Ptr : public ACE_Auto_Basic_Array_Ptr<X>
// = TITLE
- // Implements an extension to the draft C++ standard ACE_Auto_Ptr
+ // Implements an extension to the draft C++ standard auto_ptr
// abstraction.
{